======================
Tutorials and examples
======================

This page provides a collection of fittings plans and related documentation.

Ready to use
------------

Ideally, each example features a fittings plan, and step-by-step
instructions to demonstrate that it is working.

.. toctree::
   :maxdepth: 1

   tutorial.first
   tutorial.apache2
   tutorial.lemp
   tutorial.wordpress
   tutorial.nodejs
   tutorial.minio
   tutorial.docker
   tutorial.owncloud
   tutorial.openvpn
   tutorial.redis.cluster

Still on the workbench
----------------------

Some advanced use cases may require significant integration activities, and
testing, before they can be declared fully automated and ready to use.

.. toctree::
   :maxdepth: 1

   tutorial.apache2.cluster
   tutorial.mongo.cluster
   tutorial.sql.master.slave
   tutorial.samba
   tutorial.beachhead
   tutorial.gigafox

How to contribute?
------------------

We are looking for help! If you have developed an interesting use case, please
consider to add it to this list.



